/*
 * ioctl.h
 *
 * Copyright (C) 2009 Sony Corporation.
 * All rights reserved.
 *
 * $Id: ioctl.h,v 1.21 2015/07/24 04:41:34 waka Exp $
 */

#ifndef VSF_IOCTL_H
#define VSF_IOCTL_H

#include <sys/ioctl.h>			// for _IOxx
#include "asca_imsg.h"			// in ASCA Common

#define VSF_CONFS_MAX_PATH		128
#define VSF_CONFS_UMID_LENGTH	32
#define VSF_CONFS_MID_LENGTH	32

/* magic number */
#define VSF_CONFS_IOC_MAGIC		0x18

/* function number */
#define VSF_CONFS_IOC_POPEN		1
#define VSF_CONFS_IOC_UMMD		2
#define VSF_CONFS_IOC_TCPRESET	3
#define VSF_CONFS_IOC_STAT		4
#define VSF_CONFS_IOC_CLOSE		6
#define VSF_CONFS_IOC_PDSIZE	7
#define VSF_CONFS_IOC_QUIT		8
#define VSF_CONFS_IOC_UNLOCK	9
#define VSF_CONFS_IOC_LOCK		10
#define VSF_CONFS_IOC_ERRGET	11
#define VSF_CONFS_IOC_RSLEEP	12
#define VSF_CONFS_IOC_MIDGET	14
#define VSF_CONFS_IOC_MDSIZE	15
#define VSF_CONFS_IOC_REMOUNT	16

/* media id */
#define VSF_CONFS_MID_LS		0x00
#define VSF_CONFS_MID_PD		0x01
#define VSF_CONFS_MID_PD2		0x02
#define VSF_CONFS_MID_SxS1		0x10
#define VSF_CONFS_MID_SxS2		0x11
#define VSF_CONFS_MID_EXT		0x20

/* error detail number */
enum Ioctl_Detail_Error {
	Ioctl_Detail_OK = 0,
	Ioctl_Detail_Err_HPP_KLV,
	Ioctl_Detail_Err_HPP_UL,
	Ioctl_Detail_Err_HPP_Ver,
	Ioctl_Detail_Err_HPP_KAG,
	Ioctl_Detail_Err_HPP_Size,
	Ioctl_Detail_Err_HPP_Bcount,
	Ioctl_Detail_Err_HPP_OP,
	Ioctl_Detail_Err_HPP_ECUL,
	Ioctl_Detail_Err_HM_KLV,
	Ioctl_Detail_Err_HM_PPUL, /* = 10 */
	Ioctl_Detail_Err_HM_Meta,
	Ioctl_Detail_Err_HM_Umid,
	Ioctl_Detail_Err_Index_EUcount,
	Ioctl_Detail_Err_Unsuport_Struct,
	Ioctl_Detail_Err_FPS_Unkown,
	Ioctl_Detail_Err_Format_Unmatch,
	Ioctl_Detail_Err_Duration,
	Ioctl_Detail_Err_Index_KLV,
	Ioctl_Detail_Err_Index_UL,
	Ioctl_Detail_Err_Rec_Inhi, /* = 20 */
	Ioctl_Detail_Err_Emphasis_Unmatch,
	Ioctl_Detail_Err_Else =999
};

/* close error number */
enum Ioctl_Close_Error {
	Ioctl_Close_OK = 0,
	Ioctl_Close_Err_Umid_Exist,
	Ioctl_Close_War_Umid_Changed,
	Ioctl_Close_War_Dur_Changed,
	Ioctl_Close_War_Else,
	Ioctl_Close_Err_Disk_Full,
	Ioctl_Close_War_Nrt_Lack,
	Ioctl_Close_War_DataItem,
	Ioctl_Close_War_SysItem,
	Ioctl_Close_Err_Format_Unmatch,
	Ioctl_Close_Err_Else = 999
};

/* 3rd argument */
// for Partial Open
struct vsf_confs_popen_param {
	long long offset;
	long long size;
	char path[VSF_CONFS_MAX_PATH];
};
// for XDCAM STAT
struct xdcam_stat{
	AsVideoCodec v_codec;							// Video Codec
	AsFps fps;										// Frame Freq.
	unsigned long num_of_a_ch;						// Number of Audio Channels
	unsigned long clip_duration;					// Total number of frames in clip
	char umidstr[(VSF_CONFS_UMID_LENGTH * 2) + 1];	// UMID
};
struct vsf_confs_xdc_stat_param {
	char path[VSF_CONFS_MAX_PATH];
	struct xdcam_stat xdc_stat;
};
// for get PD zise
struct vsf_confs_pd_size {
	unsigned long long rt_remain_size;
	unsigned long long rt_total_size;
	unsigned long long nrt_remain_size;
	unsigned long long nrt_total_size;
};
// for get Media ID
struct vsf_confs_mid_get_param {
	unsigned int media_id;							// Media Input
	char mid[VSF_CONFS_MID_LENGTH + 1];				// Get Media ID
};
// for get Media zise
struct vsf_confs_md_size {
	unsigned int media_id;							// Media Input
	unsigned long long rt_remain_size;
	unsigned long long rt_total_size;
	unsigned long long nrt_remain_size;
	unsigned long long nrt_total_size;
};

/* 2nd argument */
#define VSF_CONFS_IOCCMD_POPEN		_IOW( VSF_CONFS_IOC_MAGIC, VSF_CONFS_IOC_POPEN, struct vsf_confs_popen_param )
#define VSF_CONFS_IOCCMD_UMMD		_IO( VSF_CONFS_IOC_MAGIC, VSF_CONFS_IOC_UMMD )
#define VSF_CONFS_IOCCMD_TCPRESET	_IOW( VSF_CONFS_IOC_MAGIC, VSF_CONFS_IOC_TCPRESET, unsigned int )
#define VSF_CONFS_IOCCMD_STAT		_IOWR( VSF_CONFS_IOC_MAGIC, VSF_CONFS_IOC_STAT, struct vsf_confs_xdc_stat_param )
#define VSF_CONFS_IOCCMD_CLOSE		_IOR( VSF_CONFS_IOC_MAGIC, VSF_CONFS_IOC_CLOSE, unsigned int )
#define VSF_CONFS_IOCCMD_PDSIZE		_IOR( VSF_CONFS_IOC_MAGIC, VSF_CONFS_IOC_PDSIZE, struct vsf_confs_pd_size )
#define VSF_CONFS_IOCCMD_QUIT		_IO( VSF_CONFS_IOC_MAGIC, VSF_CONFS_IOC_QUIT )
#define VSF_CONFS_IOCCMD_UNLOCK		_IOW( VSF_CONFS_IOC_MAGIC, VSF_CONFS_IOC_UNLOCK, unsigned int )
#define VSF_CONFS_IOCCMD_LOCK		_IOW( VSF_CONFS_IOC_MAGIC, VSF_CONFS_IOC_LOCK, unsigned int )
#define VSF_CONFS_IOCCMD_ERRGET		_IOR( VSF_CONFS_IOC_MAGIC, VSF_CONFS_IOC_ERRGET, unsigned int )
#define VSF_CONFS_IOCCMD_RSLEEP		_IOW( VSF_CONFS_IOC_MAGIC, VSF_CONFS_IOC_RSLEEP, int )
#define VSF_CONFS_IOCCMD_MIDGET		_IOWR( VSF_CONFS_IOC_MAGIC, VSF_CONFS_IOC_MIDGET, struct vsf_confs_mid_get_param )
#define VSF_CONFS_IOCCMD_MDSIZE		_IOWR( VSF_CONFS_IOC_MAGIC, VSF_CONFS_IOC_MDSIZE, struct vsf_confs_md_size )
#define VSF_CONFS_IOCCMD_REMOUNT	_IOW( VSF_CONFS_IOC_MAGIC, VSF_CONFS_IOC_REMOUNT, unsigned int )


#endif /* VSF_IOCTL_H */
